@@ -3,7 +3,7 @@ package Wiki::Toolkit;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.75';
+$VERSION = '0.78';
 
 use Carp qw(croak carp);
 use Digest::MD5 "md5_hex";
@@ -792,7 +792,8 @@ The final parameter, $requires_moderation (which defaults to false),
 is ignored except on new nodes. For existing nodes, use 
 $wiki->toggle_node_moderation to change the node moderation flag.
 
-Returns 1 on success, 0 on conflict, croaks on error.
+Returns the version of the updated node on success, 0 on conflict, croaks on
+error.
 
 B<Note> on the metadata hashref: Any data in here that you wish to
 access directly later must be a key-value pair in which the value is
@@ -852,7 +853,7 @@ sub write_node {
     if ($search and $content) {
         $search->index_node($node, $store->charset_encode($content) );
     }
-    return 1;
+    return $ret;
 }
 
 =item B<format>
@@ -925,6 +926,8 @@ sub formatter {
     return $self->{_formatter};
 }
 
+=back
+
 =head1 SEE ALSO
 
 For a very quick Wiki startup without any of that icky programming
@@ -1028,7 +1031,7 @@ Questions should go to cgi-wiki-dev@earth.li.
 =head1 COPYRIGHT
 
      Copyright (C) 2002-2004 Kake Pugh.  All Rights Reserved.
-     Copyright (C) 2006-2008 the Wiki::Toolkit team. All Rights Reserved.
+     Copyright (C) 2006-2009 the Wiki::Toolkit team. All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -1041,6 +1044,16 @@ The developer web site and bug tracker is at
 You could also subscribe to the dev list at
   http://www.earth.li/cgi-bin/mailman/listinfo/cgi-wiki-dev
 
+=head1 BUGS
+
+Versions between 0.75 and 0.78 inclusive contain a bug which prevents
+Recent Changes routines from working correctly if minor changes are excluded
+<http://www.wiki-toolkit.org/ticket/41>. You may wish to avoid upgrading to
+this version until it is fixed if this is important to you; the fix is
+however not trivial so noone has been able to step up yet.
+
+Other minor bugs are documented at <http://www.wiki-toolkit.org/report>
+
 =head1 CREDITS
 
 Various London.pm types helped out with code review, encouragement,
